/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.isobus.type;

import java.io.IOException;
import nl.cloudfarming.client.isobus.model.IsobusManager;
import nl.cloudfarming.client.logging.AppLogFactory;
import nl.cloudfarming.client.logging.AppLogger;
import org.netbeans.api.project.Project;
import org.openide.filesystems.FileObject;
import org.openide.util.Exceptions;
import org.openide.util.lookup.ServiceProvider;

/**
 * Implementation of isobusManager Is able to import and export TASKDATA.XML
 * files
 *
 * @author Merijn Zengers
 */
@ServiceProvider(service = IsobusManager.class)
public class IsobusManagerImpl implements IsobusManager {

    public final static String ISOBUS_FOLDER = "ISO11783";
    private static final AppLogger LOG = AppLogFactory.getLogger(IsobusManagerImpl.class);


    /**
     * Get all the taskdata folders from the provided project These folders
     * contain a TASKDATA.XML and optional GRD.BIN ,TLG.BIN and TLG.XML files
     *
     * @param project the project to search in
     * @return the found folders or empty array if there are no children
     */
    @Override
    public FileObject[] getTaskDataFolders(Project project) {
        FileObject isobusFolder = getIsobusFolder(project);
        return isobusFolder.getChildren();
    }

    /**
     * Returns isobusfolder inside the specified project Protected for
     * unittesting purposes!
     *
     * @param project Project to get isobusfolder from.
     * @return Isobusfolder on the filesystem
     */
    @Override
    public FileObject getIsobusFolder(Project project) {
        FileObject isobusFolder = project.getProjectDirectory().getFileObject(ISOBUS_FOLDER);
        // Create Isobusfolder if it doesn't exist
        if (isobusFolder == null) {
            try {
                isobusFolder = project.getProjectDirectory().createFolder(ISOBUS_FOLDER);
            } catch (IOException ex) {
                Exceptions.printStackTrace(ex);
            }
        }
        return isobusFolder;
    }


}
