/*
 * Copyright (c) 2012 AgroSense.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    AgroSense - initial API and implementation and/or initial documentation
 */
package nl.cloudfarming.client.isobus.type;

import com.vividsolutions.jts.geom.Geometry;
import java.awt.BorderLayout;
import java.awt.Color;
import javax.swing.Action;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JToolBar;
import nl.cloudfarming.client.geoviewer.Geometrical;
import nl.cloudfarming.client.geoviewer.render.GeometricalPreviewPanel;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;
import org.openide.windows.TopComponent;

/**
 * 
 * @author johan
 */
@MultiViewElement.Registration(
    displayName = "#LBL_TimeLogBinary_VISUAL",
iconBase = TimeLogBinaryDataObject.ICON_BASE,
mimeType = TimeLogBinaryDataObject.MIME_TYPE,
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "TimeLogBinaryVisual",
position = 2000)
@Messages("LBL_TimeLogBinary_VISUAL=Visual")
public final class TimeLogBinaryVisualElement extends JPanel implements MultiViewElement {

    private TimeLogBinaryDataObject obj;
    private JToolBar toolbar = new JToolBar();
    private transient MultiViewElementCallback callback;

    public TimeLogBinaryVisualElement(Lookup lkp) {
        obj = lkp.lookup(TimeLogBinaryDataObject.class);
        assert obj != null;
        
        //initComponents();
        setLayout(new BorderLayout());
        setBackground(Color.white);
        final Geometrical geometrical = obj.getLookup().lookup(Geometrical.class);
        final Geometry geometry = geometrical.getGeometry();
        
        if (geometry != null) {
            if (geometry.getEnvelope().getCoordinates().length >= 4) {
                add(new GeometricalPreviewPanel(geometrical), BorderLayout.CENTER);
            } else {
                add(new JLabel("Not enough distinct points to create a rectangular bounding box: "
                        + geometry.getEnvelope().toText()), BorderLayout.NORTH);
            }
        }
    }

    @Override
    public String getName() {
        return "TimeLogBinaryVisualElement";
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 400, Short.MAX_VALUE)
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 300, Short.MAX_VALUE)
        );
    }// </editor-fold>//GEN-END:initComponents

    // Variables declaration - do not modify//GEN-BEGIN:variables
    // End of variables declaration//GEN-END:variables
    @Override
    public JComponent getVisualRepresentation() {
        return this;
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public Action[] getActions() {
        return new Action[0];
    }

    @Override
    public Lookup getLookup() {
        return obj.getLookup();
    }

    @Override
    public void componentOpened() {
    }

    @Override
    public void componentClosed() {
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateName();
        }
    }

    public void updateName() {
        if (callback != null) {
            String name = obj.getName();
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(name);
            tc.setDisplayName(name);
            tc.setName(getName());
            tc.setToolTipText(getToolTipText());
        }
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback callback) {
        this.callback = callback;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }
}
